<?php

namespace FiloBlu\AdyenErrorNotificationHandler\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\StoreManagerInterface;

class Data
{
    const ADYEN_ERROR_NOTIFICATION_HANDLER_ENABLED_CONFIG_PATH = 'adyen_error_notification_handler/general/error_notification_enabled';
    const ADYEN_ERROR_NOTIFICATION_HANDLER_MESSAGES_CONFIG_PATH = 'adyen_error_notification_handler/general/error_notification_messages';
    const ADYEN_REFUSAL_REASON_CODE = 'refusalReasonCode';
    const ERROR_CODE_3DV1 = '3dv1';

    /**
     * @var ScopeConfigInterface
     */
    protected $config;

    /**
     * @var StoreManagerInterface
     */
    protected $_storeManager;

    public function __construct(
        ScopeConfigInterface $config,
        StoreManagerInterface $storeManager
    ) {
        $this->config = $config;
        $this->_storeManager = $storeManager;
    }

    public function adyenErrorNotificationHandlerIsEnabled()
    {
        return $this->config->isSetFlag(self::ADYEN_ERROR_NOTIFICATION_HANDLER_ENABLED_CONFIG_PATH);
    }

    public function getAdyenErrorNotificationMessages()
    {
        return $this->config->getValue(self::ADYEN_ERROR_NOTIFICATION_HANDLER_MESSAGES_CONFIG_PATH);
    }

    public function getStoreCode($storeId)
    {
        $store = $this->_storeManager->getStore($storeId);
        return $store->getCode();
    }

    public function getErrorsInLanguage($errorsList, $languageIso)
    {
        if(isset($errorsList[$languageIso]))
        {
            return $errorsList[$languageIso];
        }

        $language = explode('_', $languageIso);

        foreach ($language as $lang)
        {
            if(isset($errorsList[$lang]))
            {
                return $errorsList[$lang];
            }
        }

        return null;
    }

    public function getErrorByCode($errorsList, $errorCode)
    {
        if(isset($errorsList[$errorCode]))
        {
            return $errorsList[$errorCode];
        }

        return null;
    }

}