<?php

namespace FiloBlu\AdyenErrorNotificationHandler\Observer;

use FiloBlu\AdyenErrorNotificationHandler\Helper\Data;

class ErrorNotify implements \Magento\Framework\Event\ObserverInterface
{
    /**
     * @var Data
     */
    protected $dataHelper;

    public function __construct(Data $dataHelper){
        $this->dataHelper = $dataHelper;
    }

    /**
     * Execute observer
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(
        \Magento\Framework\Event\Observer $observer
    ) {
        if($this->dataHelper->adyenErrorNotificationHandlerIsEnabled())
        {
            $response = $observer->getEvent()->getResponse();
            $language = $observer->getEvent()->getLanguage();
            $is3dsV1 = $observer->getEvent()->getSecureCodeOne();

            $errorMessages = json_decode($this->dataHelper->getAdyenErrorNotificationMessages(), true);

            if(!is_null($errorMessages) && is_array($errorMessages))
            {
                $errorInLang = $this->dataHelper->getErrorsInLanguage($errorMessages, $language);

                if(!is_null($errorInLang))
                {
                    if(!$is3dsV1)
                    {
                        $error = $this->dataHelper->getErrorByCode($errorInLang, $response[$this->dataHelper::ADYEN_REFUSAL_REASON_CODE]);
                        if(!is_null($error))
                        {
                            throw new \Magento\Framework\Exception\LocalizedException(__($error));
                        }
                    }
                    else
                    {
                        $data = $observer->getEvent()->getData();
                        $messageManager = $data['messageManager'];

                        $codeToCheck = $response[$this->dataHelper::ADYEN_REFUSAL_REASON_CODE] != 0 ? $response[$this->dataHelper::ADYEN_REFUSAL_REASON_CODE] : $this->dataHelper::ERROR_CODE_3DV1;
                        $error = $this->dataHelper->getErrorByCode($errorInLang, $codeToCheck);
                        if(!is_null($error))
                        {
                            $messageManager->addErrorMessage($error);
                        }
                        else
                        {
                            $messageManager->addErrorMessage("3D-secure validation was unsuccessful");
                        }
                    }
                }
            }
        }
    }
}